| Title: | R Wrapper for Izmir Municipality Open Data Portal |
|---|---|
| Description: | Call the data wrappers for Izmir Metropolitan Municipality's Open Data Portal at <https://acikveri.bizizmir.com>. This will return all datasets formatted as Excel files (.csv or .xlsx), as well as datasets that require an API key. |
| Authors: | Ozancan Ozdemir [aut, cre] |
| Maintainer: | Ozancan Ozdemir <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-08 08:42:28 UTC |
| Source: | https://github.com/ozancanozdemir/izmir |
this function returns a data frame where character columns are encoded as UTF-8. it is a helper function in get_data_from_izmir
encoding_data(data)encoding_data(data)
data |
A data frame obtained from get_data_from_izmir |
Given a data name, this function returns the data frame
get_data_from_izmir(data_name)get_data_from_izmir(data_name)
data_name |
A data set name obtained from list_data_names() |
A data frame that shows the observations for given data name
get_data_from_izmir("asik-veysel-rekreasyon-alani-buz-pisti-kullanici-verileri")get_data_from_izmir("asik-veysel-rekreasyon-alani-buz-pisti-kullanici-verileri")
list the name of the data sets available in Izmir Open Data Portal
list_data_names()list_data_names()
A character vector that shows the name of the data set
list_data_names()list_data_names()
Given a key word, this function returns the dataset names including key word
search_data_by_keyword(key_word)search_data_by_keyword(key_word)
key_word |
A data set name which is a character object |
A character vector object that shows the name of the datasets including key word
search_data_by_keyword("doktor")search_data_by_keyword("doktor")